<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>

<xsl:template match="eit">

	<tv>
		<xsl:apply-templates select="//service" />
		<xsl:apply-templates select="//event" />
	</tv>

</xsl:template>

<xsl:template match="service" >

	<channel>
		<xsl:attribute name="id"><xsl:value-of select="@id" /></xsl:attribute>

		<display-name lang="en">
			<xsl:value-of select="name" />
		</display-name>
	</channel>

</xsl:template>

<xsl:template match="event" >

	<programme>
		<xsl:attribute name="channel"><xsl:value-of select="@service" /></xsl:attribute>
		<xsl:attribute name="start"><xsl:value-of select="@start" /></xsl:attribute>
		<xsl:attribute name="stop"><xsl:value-of select="@stop" /></xsl:attribute>

		<title lang="en">

			<xsl:call-template name='titlecase'>
			<xsl:with-param name='toconvert' select="short_desc/title" />
			</xsl:call-template>

		</title>

		<xsl:if test="short_desc/title != short_desc/text"> 
			<sub-title lang="en">
				<xsl:value-of select="short_desc/text" />
			</sub-title>
		</xsl:if>

		<desc lang="en">
			<xsl:value-of select="substring(substring-before(extended_desc,' [Program info'), 5)" />
		</desc>

		<category lang="en">
			<xsl:value-of select="category" />
		</category>

	</programme>

</xsl:template>

<xsl:template match="extended_desc" >

	<xsl:value-of select="." />

</xsl:template>

<xsl:template name='titlecase'>
	<xsl:param name='toconvert' />
	<xsl:call-template name='convertpropercase'>
	<xsl:with-param name='toconvert'>
		<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
	</xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template name='convertpropercase'>

	<xsl:param name='toconvert' />

	<xsl:if test="string-length($toconvert) > 0">
		<xsl:variable name='f' select='substring($toconvert, 1, 1)' />
		<xsl:variable name='s' select='substring($toconvert, 2)' />
		
		<xsl:value-of select="translate($f,$lcletters,$ucletters)"/>
	
		<xsl:choose>
			<xsl:when test="contains($s,' ')">
				<xsl:value-of select='substring-before($s," ")'/>&#160;<xsl:call-template name='convertpropercase'>
				<xsl:with-param name='toconvert' select='substring-after($s," ")' />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select='$s'/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:if>

</xsl:template>

   
</xsl:stylesheet>
